@@ -68,7 +68,7 @@ def test_import_without_clock_realtime():
         spec.loader.exec_module(module)  # type: ignore[union-attr]
 
     finally:
-        time.CLOCK_REALTIME = orig
+        time.CLOCK_REALTIME = orig  # type: ignore[misc]
 
     # No assertions - testing for coverage only
 
@@ -243,23 +243,6 @@ def test_time_localtime_arg():
         assert local_time.tm_mday == 1
 
 
-def test_time_montonic():
-    with time_machine.travel(EPOCH, tick=False) as t:
-        assert time.monotonic() == EPOCH
-        t.shift(1)
-        assert time.monotonic() == EPOCH + 1
-
-
-def test_time_monotonic_ns():
-    with time_machine.travel(EPOCH, tick=False) as t:
-        assert time.monotonic_ns() == int(EPOCH * NANOSECONDS_PER_SECOND)
-        t.shift(1)
-        assert (
-            time.monotonic_ns()
-            == int(EPOCH * NANOSECONDS_PER_SECOND) + NANOSECONDS_PER_SECOND
-        )
-
-
 def test_time_strftime_format():
     with time_machine.travel(EPOCH):
         assert time.strftime("%Y-%m-%d") == "1970-01-01"
@@ -531,9 +514,70 @@ def test_destination_timedelta_nested():
         assert time.time() == EPOCH + 10.0
 
 
-@time_machine.travel("1970-01-01 00:01 +0000")
-def test_destination_string():
-    assert time.time() == EPOCH + 60.0
+def test_destination_string_no_dateutil_unparsable():
+    with (
+        mock.patch.object(time_machine, "HAVE_DATEUTIL", new=False),
+        pytest.raises(ValueError) as excinfo,
+        time_machine.travel("the future"),
+    ):
+        pass  # pragma: no cover
+    assert excinfo.value.args == ("Invalid isoformat string: 'the future'",)
+
+
+@pytest.mark.parametrize(
+    ("string", "expected_time"),
+    [
+        ("1970-01-01 00:00:00", EPOCH),
+        ("1970-01-01 00:01:01", EPOCH + 61.0),
+        ("1970-01-01", EPOCH),
+    ],
+)
+def test_destination_string_no_dateutil(string, expected_time):
+    with (
+        mock.patch.object(time_machine, "HAVE_DATEUTIL", new=False),
+        time_machine.travel(string),
+    ):
+        assert time.time() == expected_time
+
+
+@pytest.mark.skipif(
+    sys.version_info < (3, 11),
+    reason="datetime.fromisoformat extended formats added in 3.11",
+)
+@pytest.mark.parametrize(
+    ("string", "expected_time"),
+    [
+        ("19700101T000102", EPOCH + 62.0),
+        ("1970-01-01T00:00:05+01:00", EPOCH - 3600.0 + 5),
+    ],
+)
+def test_destination_string_no_dateutil_extended_formats(string, expected_time):
+    with (
+        mock.patch.object(time_machine, "HAVE_DATEUTIL", new=False),
+        time_machine.travel(string),
+    ):
+        assert time.time() == expected_time
+
+
+def test_destination_string_unparsable_dateutil():
+    with (
+        pytest.raises(ValueError) as excinfo,
+        time_machine.travel("the future"),
+    ):
+        pass  # pragma: no cover
+    assert excinfo.value.args == ("Unknown string format: %s", "the future")
+
+
+@pytest.mark.parametrize(
+    ("string", "expected_time"),
+    [
+        ("1st January 1970 00:03:03", EPOCH + 183.0),
+        ("1st Jan 1970", EPOCH),
+    ],
+)
+def test_destination_string_dateutil(string, expected_time):
+    with time_machine.travel(string):
+        assert time.time() == expected_time
 
 
 @pytest.mark.parametrize(
@@ -594,6 +638,54 @@ def test_coroutine_decorator():
     assert recorded_time == EPOCH + 140.0
 
 
+def test_async_context_manager():
+    recorded_time = None
+
+    async def record_time() -> None:
+        nonlocal recorded_time
+        async with time_machine.travel(EPOCH + 150.0):
+            recorded_time = time.time()
+
+    asyncio.run(record_time())
+
+    assert recorded_time == EPOCH + 150.0
+
+
+def test_async_context_manager_stops_properly():
+    recorded_times = []
+
+    async def record_times() -> None:
+        recorded_times.append(time.time())
+
+        async with time_machine.travel(EPOCH + 160.0):
+            recorded_times.append(time.time())
+
+        recorded_times.append(time.time())
+
+    asyncio.run(record_times())
+
+    assert recorded_times[0] >= LIBRARY_EPOCH
+    assert recorded_times[1] == EPOCH + 160.0
+    assert recorded_times[2] >= LIBRARY_EPOCH
+
+
+def test_async_context_manager_traveller():
+    recorded_time = None
+    shifted_time = None
+
+    async def test_traveller() -> None:
+        nonlocal recorded_time, shifted_time
+        async with time_machine.travel(EPOCH + 170.0, tick=False) as traveller:
+            recorded_time = time.time()
+            traveller.shift(10.0)
+            shifted_time = time.time()
+
+    asyncio.run(test_traveller())
+
+    assert recorded_time == EPOCH + 170.0
+    assert shifted_time == EPOCH + 180.0
+
+
 def test_class_decorator_fails_non_testcase():
     with pytest.raises(TypeError) as excinfo:
 
@@ -948,6 +1040,79 @@ def test_fixture_shift_without_move_to(time_machine):
     )
 
 
+def test_marker_function(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        import time
+
+        @pytest.fixture
+        def current_time():
+            return time.time()
+
+        @pytest.mark.time_machine(0)
+        def test(current_time):
+            assert current_time < 10.0
+    """
+    )
+
+    result = testdir.runpytest("-v", "-s")
+    result.assert_outcomes(passed=1)
+
+
+def test_marker_and_fixture(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        import time
+
+        @pytest.mark.time_machine(0)
+        def test(time_machine):
+            assert time.time() < 10.0
+            time_machine.shift(100)
+            assert 100.0 <= time.time() < 110.0
+            time_machine.move_to(0)
+            assert time.time() < 10.0
+        """
+    )
+    result = testdir.runpytest("-v", "-s")
+    result.assert_outcomes(passed=1)
+
+
+def test_marker_class(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        import time
+
+        @pytest.mark.time_machine(0)
+        class TestTimeMachine:
+            def test(self):
+                assert time.time() < 10.0
+    """
+    )
+
+    result = testdir.runpytest("-v", "-s")
+    result.assert_outcomes(passed=1)
+
+
+def test_marker_module(testdir):
+    testdir.makepyfile(
+        """
+        import pytest
+        import time
+
+        pytestmark = pytest.mark.time_machine(0)
+
+        def test_module():
+            assert time.time() < 10.0
+    """
+    )
+
+    result = testdir.runpytest("-v", "-s")
+    result.assert_outcomes(passed=1)
+
+
 # escape hatch tests
 
 
@@ -966,6 +1131,10 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.datetime.datetime.now()
             assert eh_now >= real_now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.datetime.datetime.now()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     def test_datetime_now_tz(self):
         real_now = dt.datetime.now(tz=dt.timezone.utc)
 
@@ -980,6 +1149,10 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.datetime.datetime.utcnow()
             assert eh_now >= real_now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.datetime.datetime.utcnow()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     @py_have_clock_gettime
     def test_time_clock_gettime(self):
         now = time.clock_gettime(time.CLOCK_REALTIME)
@@ -988,6 +1161,10 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.time.clock_gettime(time.CLOCK_REALTIME)
             assert eh_now >= now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.clock_gettime(time.CLOCK_REALTIME)
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     @py_have_clock_gettime
     def test_time_clock_gettime_ns(self):
         now = time.clock_gettime_ns(time.CLOCK_REALTIME)
@@ -998,6 +1175,10 @@ class TestEscapeHatch:
             )
             assert eh_now >= now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.clock_gettime_ns(time.CLOCK_REALTIME)
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     def test_time_gmtime(self):
         now = time.gmtime()
 
@@ -1005,6 +1186,10 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.time.gmtime()
             assert eh_now >= now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.gmtime()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     def test_time_localtime(self):
         now = time.localtime()
 
@@ -1012,18 +1197,9 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.time.localtime()
             assert eh_now >= now
 
-    def test_time_monotonic(self):
-        with time_machine.travel(LIBRARY_EPOCH):
-            # real monotonic time counts from a small number
-            assert time_machine.escape_hatch.time.monotonic() < LIBRARY_EPOCH
-
-    def test_time_monotonic_ns(self):
-        with time_machine.travel(LIBRARY_EPOCH):
-            # real monotonic time counts from a small number
-            assert (
-                time_machine.escape_hatch.time.monotonic_ns()
-                < LIBRARY_EPOCH * NANOSECONDS_PER_SECOND
-            )
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.localtime()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
 
     def test_time_strftime_no_arg(self):
         today = dt.date.today()
@@ -1033,6 +1209,10 @@ class TestEscapeHatch:
             eh_today = dt.datetime.strptime(eh_formatted, "%Y-%m-%d").date()
             assert eh_today >= today
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.strftime("%Y-%m-%d")
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     def test_time_strftime_arg(self):
         with time_machine.travel(EPOCH):
             formatted = time_machine.escape_hatch.time.strftime(
@@ -1048,9 +1228,17 @@ class TestEscapeHatch:
             eh_now = time_machine.escape_hatch.time.time()
             assert eh_now >= now
 
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.time()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
+
     def test_time_time_ns(self):
         now = time.time_ns()
 
         with time_machine.travel(EPOCH):
             eh_now = time_machine.escape_hatch.time.time_ns()
             assert eh_now >= now
+
+        with pytest.raises(ValueError) as excinfo:
+            time_machine.escape_hatch.time.time_ns()
+        assert excinfo.value.args == ("Not currently time-travelling.",)
